@@ -1,10 +1,9 @@
-# This file uses except* clause in Python 3.11.
+# This file uses pattern matching introduced in Python 3.10.
 
 
-try:
-    some_call()
-except* Error as e:
-    pass
+match http_code:
+    case 404:
+        print("Not found")
 
 
 with \
@@ -19,13 +18,12 @@ with \
 # output
 
 
-# This file uses except* clause in Python 3.11.
+# This file uses pattern matching introduced in Python 3.10.
 
 
-try:
-    some_call()
-except* Error as e:
-    pass
+match http_code:
+    case 404:
+        print("Not found")
 
 
 with (
